{{ template "header.html" . }}
<main>
<div class="outline">
{{ .Person.Display }} - {{ .Person.Name }}
- <a href="{{ .Person.APid }}">{{ .Person.APid }}</a>
<p>{{ .Person.HTAbout }}
{{ if .UserInfo }}
{{ if .Person.IsSubbed .UserInfo.ID }}
<form class="inline" action="/unsubscribe" method="POST">
<input type="hidden" name="person" value="{{ .Person.Name }}">
<button tabindex=1>unfollow</button>
</form>
{{ else }}
<form class="inline" action="/subscribe" method="POST">
<input type="hidden" name="person" value="{{ .Person.Name }}">
<button tabindex=1>follow</button>
</form>
{{ end }}
<button tabindex=1><a href="/report?what={{ .Person.APid }}">report</a></button>
{{ end }}
{{ if .UserInfo.IsAdmin }}
<form class="inline" action="/saveperson" method="POST">
<input type="hidden" name="CSRF" value="{{ .SaveCSRF }}">
<input type="hidden" name="delete" value="1">
<input type="hidden" name="name" value="{{ .Person.Name }}">
<input tabindex=1 type="text" name="confirm" autocomplete=off placeholder="confirm">
<button tabindex=1>delete</button>
</form>
{{ end }}
</div>
{{ template "multipost.html" . }}
</main>
