{{ template "header.html" . }}
<main>
<h2>Search</h2>
<p>Try the following:
<ul>
<li><i>text</i> - search for text
<li><i>site:name</i> - search for links to site
<li><i>title:text</i> - search for text in the title
<li><i>https://url</i> - search for specific <b>AP</b> object
<li><i>@name</i> - search for webfinger user
</ul>
</main>
