{{ template "header.html" . }}
{{ if .UserInfo }}
{{ template "headergroups.html" . }}
{{ end }}
<main>
{{ $userid := .UserID }}
{{ range .Groups }}
<div class="outline">
<a href="{{ .Rel }}">{{ .Name }}</a> - {{ .Display }}
{{ if .IsRemote }} - <a href="{{.APid }}">{{ .APid }}</a>{{ end }}
{{ if .IsSubbed $userid }} - (subbed){{ end }}
</div>
{{ end }}
</main>
