{{ template "header.html" . }}
<header>
<div id="submenu">
<span><a href="/help/intro.1.html">intro</a></span>
<span><a href="/help/azorius.1.html">user manual</a></span>
<span><a href="/help/azorius.8.html">administration</a></span>
<span><a href="/help/activitypub.7.html">reference</a></span>
</div>
</header>
<main class="manual">
{{ .Help }}
</main>
