{{ template "header.html" . }}
<main>
<p>Post: <a href="{{ .Post.Rel }}">{{ .Post.Title }}</a></p>
<p>Link: <a href="{{ .Comment.APid }}">{{ .Comment.APid }}</a></p>
{{ template "fragcomment.html" map "Comment" .Comment "UserInfo" .UserInfo }}
{{ if .UserInfo }}
{{ if .Comment.CanMod .UserInfo }}
<button><a href="{{ .Comment.Rel }}/edit">edit</a></button>
{{ end }}
<button><a href="/report?what={{ .Comment.APid }}">report</a></button>
{{ end }}
</main>
