<header>
<nav id="submenu">
<span><a href="/admin">site</a></span>
<span><a href="/admin/groups">groups</a></span>
<span><a href="/admin/users">users</a></span>
<span><a href="/admin/peers">peers</a></span>
<span><a href="/admin/filters">filters</a></span>
<span><a href="/admin/reports">reports</a></span>
</nav>
</header>
