<!doctype html>
<html>
<head>
<title>{{ or .Title .ServerName }}</title>
<link href="/style.css{{ .StyleParam }}" rel="stylesheet">
{{ if .LocalStyleParam }}
<link href="/local.css{{ .LocalStyleParam }}" rel="stylesheet">
{{ end }}
{{ .OGSummary }}
{{ .APAltLink }}
{{ .CanonLink }}
<link href="/icon.png" rel="icon">
<meta name="theme-color" content="#117">
<meta name="viewport" content="width=device-width">
<meta name="referrer" content="no-referrer">
<script src="/script.js{{ .JSParam }}" defer></script>
</head>
<body>
{{ with .SiteAlert }}
<div class="outline">{{ . }}</div>
{{ end }}
<header>
<nav id="topmenu">
{{ if .TopLink }}<span><button id="btnrefresh" data-toplink="{{ .TopLink }}">refresh</button></span>
{{ else }}
<span><a id="homelink" href="/">home</a></span>
{{ end }}
{{ if .UserInfo }}
<span><a href="/front">front</a></span>
{{ end }}
<span><a href="/groups">groups</a></span>
<span><a href="/about">about</a></span>
{{ if .UserInfo }}
{{ if .UserInfo.IsAdmin }}
<span><a href="/admin">admin</a></span>
{{ end }}
<span><a href="/notifs" id="notifholder">notifs{{ with .NumNotifs }} ({{ . }}){{ end }}</a></span>
<span><a href="/account">{{ .UserInfo.Name }}</a>{{ if not .UserInfo.IsApproved }} (unapproved){{ end }}</span>
<form action="/search" method="GET">
<input tabindex=10 type="text" name="q" autocomplete=off size=10 placeholder="search">
</form>
{{ else }}
<span><a href="/login">login</a></span>
{{ end }}
<span><a href="/help/intro.1.html">help</a></span>
</nav>
</header>
