html {
	--bg-page: #eef;
	--fg: #117;
	--hl: #117;
	--menubg: #117;
	--menufg: #bbf;
}
@media (prefers-color-scheme: dark) {
html {
	--bg-page: #001;
	--fg: #99f;
	--hl: #99f;
	--menubg: #005;
	--menufg: #99f;
}
img {
	opacity: .5;
	transition: opacity .5s ease-in-out;
}
img:hover {
	opacity: 1;
}
}

body {
	background: var(--bg-page);
	color: var(--fg);
	font-size: 1em;
	word-wrap: break-word;
	font-family: sans-serif, "Noto Color Emoji";
	line-height: 1.2;
	overscroll-behavior-y: contain;
	margin: 0;
}
main {
	padding: 0.5em;
}
pre, code {
	white-space: pre-wrap;
}
blockquote {
	margin-left: 0em;
	margin-bottom: 0em;
	padding-left: 0.5em;
	border-left: 1px solid var(--fg);
}
div.outline {
	margin: 0.5em;
	padding: 0.25em;
	border: 1px solid var(--fg);
}
div.commentbox {
	margin-left: 0.35em;
	margin-right: 0.5em;
}
div.comment {
	border-left: 1px solid var(--fg);
	border-top: 1px solid var(--fg);
	margin: 0 0 0.25em 0.25em;
	padding: 0.25em 0 0 0.25em;
}
p.comment {
	margin: 0 0 0.75em 0.25em;
	padding: 0.25em 0 0 0.25em;
}
.subtlelinks a {
	text-decoration: none;
}
.subtlelinks a:hover {
	text-decoration: underline;
}
cite {
	margin-left: 2em;
}
table {
	display: block;
	max-width: 100%;
	overflow-x: auto;
}
table.chat td {
	border-left: 1px solid var(--fg);
	padding: 0 0.25em 0 0.25em;
}
table.chat p {
	margin: 0;
}
a {
	color: var(--fg);
	cursor: pointer;
}
form, input, textarea {
	font-family: monospace, "Noto Color Emoji";
}
p {
	margin-top: 1em;
	margin-bottom: 1em;
}
input {
	background: var(--bg-page);
	color: var(--fg);
	font-size: 1.0em;
	line-height: 1.2em;
	padding: 0.4em;
	border: 1px solid var(--fg);
}
main input {
	box-sizing: border-box;
	width: 100%;
}
main input.small {
	width: 14em;
}
form.inline input{
	width: 8em;
}
body > header {
	margin: 0em auto;
	font-size: 1.5em;
}
body > header span {
	margin-left: 2em;
}
body > header form {
	display: inline;
	font-size: 0.8em;
	margin-left: 2em;
}
body > header p {
	padding: 1em;
}
#topmenu {
	padding: 0.1em;
	background-color: var(--menubg);
	color: var(--menufg);
}
#topmenu a {
	color: var(--menufg);
}
#submenu {
	padding: 0.2em;
	background-color: var(--menufg);
}
#submenu a {
	color: var(--menubg);
}
main {
	max-width: 1200px;
	margin: auto;
	font-size: 1.5em;
}
hr {
	border-color: var(--hl);
}
label {
	font-size: 0.8em;
}
label.button, button, select, button a {
	font-size: 1.0em;
	font-family: monospace;
	color: var(--menufg);
	background: var(--menubg);
	border: 1px solid var(--hl);
	padding: 0.5em;
	white-space: nowrap;
}
button a {
	border: none;
}
.buttonarray {
	margin-top: -2.0em;
}
.buttonarray button, .buttonarray > span {
	margin-top: 2.0em;
	display: inline-block;
}
button a {
	text-decoration: none;
}
button {
	cursor: pointer;
}
form {
	margin-top: 1em;
}
.inline {
	display: inline;
}
textarea {
	padding: 0.5em;
	font-size: 1em;
	background: var(--bg-page);
	color: var(--fg);
	width: 100%;
	height: 4em;
	margin-bottom: 0.5em;
	box-sizing: border-box;
	max-width: 100%;
	border: 1px solid var(--fg);
}
textarea.large {
	height: 12em;
}
textarea.medium {
	height: 6em;
}
textarea.small {
	height: 4.5em;
}
textarea.cangrow {
	height: auto;
}
input[type="checkbox"] {
	position: fixed;
	top: -9999px;
}
input[type="checkbox"] + span:after {
	content: "no";
}
input[type="checkbox"]:checked + span:after {
	content: "yes";
}
input[type="checkbox"]:focus + span:after {
	outline: 1px solid var(--fg);
}
input[type=file] {
	display: none;
}
h1, h2 {
	font-size: 1.2em;
}
h3, h4 {
	font-size: 1.1em;
}
h1, h2, h3, h4 {
	margin-top: 0;
}
.size08 {
	font-size: 0.8em;
}
.text-left {
	text-align: left;
}
.text-right {
	text-align: right;
}
.text-center {
	text-align: center;
}

.manual {
	padding-left: 2em;
}
.manual .head, .manual .foot {
	display: none;
}
.manual div.Nd {
	display: inline;
}
.manual h1, .manual h2 {
	margin-top: 1em;
	margin-left: -1em;
}
.manual .Bl-tag {
	margin-top: 0.6em;
	margin-left: 5.5em;
}
.manual .Bl-tag > dt {
	float: left;
	margin-top: 0em;
	margin-left: -5.5em;
	padding-right: 0.5em;
	vertical-align: top;
}
.manual .Bl-tag > dd {
	clear: right;
	width: 100%;
	margin-top: 0em;
	margin-left: 0em;
	margin-bottom: 0.6em;
	vertical-align: top;
	overflow: auto;
}


img, video {
	max-width: 100%;
	max-height: 600px;
	background: var(--bg-page);
	display: block;
}
img.preview {
	max-height: 240px;
}

html {
	--red: #cc0000;
	--green: #007700;
}
@media (prefers-color-scheme: dark) {
html {
	--red: #bb5555;
	--green: #55bb55;
}
}


code .kw { font-weight: bold; }
code .bi { font-weight: bold; }
code .st { color: var(--red); }
code .nm { color: var(--green); }
code .op { color: var(--red); }
code .tp { font-weight: bold; }
code .cm { font-style: italic; }
code .al { color: var(--green); }
code .dl { color: var(--red); }

@media screen and (max-width: 1360px) {
	.nophone {
		display: none;
	}
}
@media screen and (max-width: 740px) {
	body {
		font-size: 12px;
	}
@media print {
	#topmenu, #topspacer, #infobox, #refreshbox, .actions {
		display: none;
	}
	html {
		--bg-page: white;
		--fg: black;
	}
}
/*
 * CSP: style-src: self
 */
