{{ $userinfo := .UserInfo }}
{{ with .Comment }}
<div class="comment" id="c{{ .Xid }}">
<span class="subtlelinks">
{{ if $userinfo }}
<a href="/u/{{ .PersonName }}">{{ .PersonName }}</a>
{{ else }}
{{ .PersonName }}
{{ end }}
on {{ .WebDate }}
{{ if $userinfo }}
<a href="{{ .Rel }}">#</a>
<a href="/reply?xid={{ .Xid }}">reply</a>
{{ end }}
{{ with .Next }}<a href="#c{{ .Xid }}">next</a>{{ end }}
<a class=collapselink>collapse</a>
</span>
<div>
<p>{{ .HTContent }}
{{ range .Kids }}
{{ template "fragcomment.html" map "Comment" . "UserInfo" $userinfo }}
{{ end }}
</div>
</div>
{{ end }}
