{{ template "header.html" . }}
{{ template "headeronegroup.html" . }}
<main>
<div class="outline">
{{ .Group.Display }} - {{ .Group.Name }}
<table class="chat">
{{ range .Chats }}
<tr><td>{{ .Timestamp }} {{ .ShortName }}<td>{{ .HTContent }}
{{ end }}
</table>
{{ if .UserInfo }}{{ if .UserInfo.IsApproved }}
<form action="/savechat" method="POST">
<input type="hidden" name="CSRF" value="{{ .SaveCSRF }}">
<input type="hidden" name="group" value="{{ .Group.Name }}">
<textarea tabindex=1 class="small" name="content"></textarea>
<button tabindex=1>chat</button>
</form>
{{ end }}{{ end }}
</main>
