{{ template "header.html" . }}
{{ template "headeronegroup.html" . }}
<main>
{{ range .Reports }}
<div class="outline">
report
<br>from: {{ .Who }}
<br>what: <a href="{{ .Link }}">{{ .What }}</a>
<br>why: {{ .Why }}
</div>
{{ end }}
</main>
