{{ template "header.html" . }}
{{ template "adminheader.html" . }}
<main>
Site admin.
<form id="aboutform" action="/saveadmin" method="POST">
<input type="hidden" name="CSRF" value="{{ .SaveCSRF }}">
<input type="hidden" name="pg" value="site">

<p>About message:
<br><textarea class="large" name="aboutmsg">{{ .AboutMsg }}</textarea>

<p>Site alert:
<br><textarea class="small" name="sitealert">{{ .SiteAlertTxt }}</textarea>

<p>Login message:
<br><textarea class="medium" name="loginmsg">{{ .LoginMsg }}</textarea>

<p><label class="button" for="allowsignup">allow signups:</label>
<input tabindex=1 type="checkbox" id="allowsignup" name="allowsignup" value="allowsignup" {{ if .AllowSignup }}checked{{ end }}><span></span>

<p><label class="button" for="opensignups">open signups:</label>
<input tabindex=1 type="checkbox" id="opensignups" name="opensignups" value="opensignups" {{ if .OpenSignups }}checked{{ end }}><span></span>

<p>Signup message:
<br><textarea class="medium" name="signupmsg">{{ .SignupMsg }}</textarea>

<p><label class="button" for="enablefedi">enable federation:</label>
<input tabindex=1 type="checkbox" id="enablefedi" name="enablefedi" value="enablefedi" {{ if .EnableFedi }}checked{{ end }}><span></span>

<p><button>save site settings</button>
</form>
</main>
