{{ template "header.html" . }}
{{ template "adminheader.html" . }}
<main>
Site Filters.
{{ $savecsrf := .SaveCSRF }}
{{ $saveaction := .SaveAction }}
{{ range .Filters }}
<div class="outline">
{{ .Name }} {{ .Notes }} [{{ .Type }}] match:{{ .Matcher }} actions:{{ .Actions }}
<form class="inline" action="{{ $saveaction }}" method="POST">
<input type="hidden" name="CSRF" value="{{ $savecsrf }}">
<input type="hidden" name="pg" value="filters">
<input type="hidden" name="delete" value="1">
<input type="hidden" name="filterid" value="{{ .ID }}">
<button>delete</button>
</form>
</div>
{{ end }}
{{ template "formfilter.html" . }}
</main>
