{{ template "header.html" . }}
{{ template "adminheader.html" . }}
<main>
Admin groups.
<form id="aboutform" action="/saveadmin" method="POST">
<input type="hidden" name="CSRF" value="{{ .SaveCSRF }}">
<input type="hidden" name="pg" value="reports">

{{ range .Reports }}
<div class="outline">
report:
<br>from: {{ .Who }}
<br>what: <a href="{{ .Link }}">{{ .What }}</a>
<br>why: {{ .Why }}
</div>
{{ end }}

<p><button>save reports</button>
</form>
</main>
