{{ template "header.html" . }}
<main>
{{ range .Notifs }}
<div class="outline">
{{ if .Flags }}<b>{{ end }}{{ .Msg }}{{ if .Flags }}</b>{{ end }} <a href="{{ .Url }}">link</a>
</div>
{{ end }}
</main>
