{{ template "header.html" . }}
<main>
<div class="outline">
The bad thing: {{ .What }}
<form action="/savereport" method="POST">
<input type="hidden" name="CSRF" value="{{ .SaveCSRF }}">
<input type="hidden" name="what" value="{{ .What }}">
<input type="hidden" name="where" value="{{ .Where }}">
Create a new report.
<br><textarea class="medium" tabindex=1 name="why"></textarea>
<br><button tabindex=1>create</button>
</form>
</div>
</main>
