{{ template "header.html" . }}
{{ template "adminheader.html" . }}
<main>
Admin groups.
<form id="aboutform" action="/saveadmin" method="POST">
<input type="hidden" name="CSRF" value="{{ .SaveCSRF }}">
<input type="hidden" name="pg" value="groups">

{{ range .Groups }}
<div class="outline">
group: <a href="{{ .Rel }}">{{ .Name }}</a> {{ .APid }}

<p><label class="button" for="onfront{{.ID}}">show on front:</label>
<input tabindex=1 type="checkbox" id="onfront{{.ID}}" name="onfront{{.ID}}" value="1" {{ if .OnFront }}checked{{ end }}><span></span>
<label class="button" for="delete{{.ID}}">delete:</label>
<input tabindex=1 type="checkbox" id="delete{{.ID}}" name="delete{{.ID}}" value="1"><span></span>
</div>
{{ end }}

<p><button>save groups changes</button>
</form>
</main>
