{{ template "header.html" . }}
{{ template "adminheader.html" . }}
<main>
Admin users.
<form id="aboutform" action="/saveadmin" method="POST">
<input type="hidden" name="CSRF" value="{{ .SaveCSRF }}">
<input type="hidden" name="pg" value="users">

{{ range .Users }}
<div class="outline">
user: {{ .Name }} {{ if .IsAdmin }} ADMIN! {{ end }}
<p>about: <span class="size08">{{ .Person.About }}</span>
<p><label class="button" for="isapproved{{.ID}}">approved:</label>
<input tabindex=1 type="checkbox" id="isapproved{{.ID}}" name="isapproved{{.ID}}" value="1" {{ if .IsApproved }}checked{{ end }}><span></span>
<label class="button" for="delete{{.ID}}">delete:</label>
<input tabindex=1 type="checkbox" id="delete{{.ID}}" name="delete{{.ID}}" value="1"><span></span>
</div>
{{ end }}

<p><button>save user changes</button>
</form>
</main>
